@@ -338,7 +338,8 @@ class Project(SquadObject):
     attrs = ['id', 'custom_email_template', 'data_retention_days', 'description',
              'enabled_plugins_list', 'full_name', 'group', 'html_mail', 'important_metadata_keys',
              'is_archived', 'is_public', 'moderate_notifications', 'name', 'notification_timeout',
-             'slug', 'url', 'wait_before_notification']
+             'slug', 'url', 'wait_before_notification', 'force_finishing_builds_on_timeout',
+             'build_confidence_count', 'build_confidence_threshold']
 
     def builds(self, count=DEFAULT_COUNT, **filters):
         filters.update({'project': self.id})
@@ -400,6 +401,21 @@ class Project(SquadObject):
             # TODO: make enabled_plugins_list optional
             self.enabled_plugins_list = ['linux-log-parser']
 
+    __basic_settings__ = None
+
+    @property
+    def basic_settings(self):
+        if self.__basic_settings__ is None:
+            endpoint = '%s%d/basic_settings' % (self.endpoint, self.id)
+            response = SquadApi.get(endpoint)
+            objects = self.__fill__(ProjectBasicSettings, [response.json()])
+            self.__basic_settings__ = first(objects)
+        return self.__basic_settings__
+
+
+class ProjectBasicSettings(SquadObject):
+    pass
+
 
 class Build(SquadObject):
 
